pub struct FrameField {
pub title: String,
pub source_plot: String,
pub frame_kind: AnalysisKind,
pub samples: Vec<FrameSample>,
}Expand description
A sampled moving frame field along a curve, used to drive animated frame overlays.
Fields
title: Stringsource_plot: Stringframe_kind: AnalysisKindsamples: Vec<FrameSample>Trait Implementations
Sourceimpl Clone for FrameField
impl Clone for FrameField
Sourcefn clone(&self) -> FrameField
fn clone(&self) -> FrameField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FrameField
impl Debug for FrameField
Sourceimpl PartialEq for FrameField
impl PartialEq for FrameField
Sourcefn eq(&self, other: &FrameField) -> bool
fn eq(&self, other: &FrameField) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FrameField