pub struct Resolution {
pub u: u32,
pub v: u32,
}Expand description
Mesh sampling resolution for evaluating plot functions on a grid.
u samples along the first axis, v along the second.
Default 100×100 gives smooth surfaces for typical analytical functions.
Fields
u: u32v: u32Trait Implementations
Sourceimpl Clone for Resolution
impl Clone for Resolution
Sourcefn clone(&self) -> Resolution
fn clone(&self) -> Resolution
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Resolution
impl Debug for Resolution
Sourceimpl Default for Resolution
impl Default for Resolution
Sourceimpl<'de> Deserialize<'de> for Resolution
impl<'de> Deserialize<'de> for Resolution
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for Resolution
impl PartialEq for Resolution
Sourcefn eq(&self, other: &Resolution) -> bool
fn eq(&self, other: &Resolution) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Resolution
impl Serialize for Resolution
impl Copy for Resolution
impl Eq for Resolution
impl StructuralPartialEq for Resolution